-inherit boilerplate_rapydscript.html -block title Progress Bar (RapydScript Version) -block extrahead =parent.extrahead() link rel='stylesheet' href='styles.styl' header h1 = title() div.info div.percent 0% div.progress div.progress-bar.progress-bar-info.progress-bar-striped role='progressbar' aria-valuenow='0' aria-valuemin='0' aria-valuemax='100' span.sr-only 0% button.btn.btn-primary Stop div#output